@@ -19,8 +19,7 @@ assign("plot.new",
 assign("cleanEx",
        function(env = .GlobalEnv) {
 	   rm(list = ls(envir = env, all.names = TRUE), envir = env)
-           RNGkind("Wichmann-Hill", "default")
-	   assign(".Random.seed", c(0, rep(7654, 3)), pos = 1)
+           assign(".Random.seed", as.integer(c(0, rep(7654, 3))), envir=.GlobalEnv)
        },
        env = .CheckExEnv)
 assign("..nameEx", "__{must remake R-ex/*.R}__", env = .CheckExEnv) # for now
